Embedding Listings
==================

There are currently 3 different types of listing embeddings available:

- The *Listing Collection*
- The *Recent Listings*
- The *Featured Listings*

The following sections will show you how you can enable and configure those embeddings.


Activate a Listing Collection
-----------------------------

At first, open the **Actions**-menu and select **Activate Listing Collection**:

.. image:: ../_images/activate_listing_collection.png

When the **Listing Collection** was activated, you will see a status message:

.. image:: ../_images/activate_listing_collection_done.png

To configure the **Listing Collection** click on the new link **Configure Listing Collection**.
The configuration form opens in a nice overlay:

.. image:: ../_images/configure_listing_collection.png

Once all search criterias are entered click the **Save** button.

To de-activate the **Listing Collection** again, open the **Actions**-menu and select **Deactivate Listing Collection**:

.. image:: ../_images/deactivate_listing_collection.png

When the **Listing Collection** was deactivated, you will see a status message:

.. image:: ../_images/deactivate_listing_collection_done.png


Activate Recent Listings
------------------------


Activate Featured Listings
--------------------------
